Index: webrtc/modules/bitrate_controller/bitrate_controller_impl.h |
diff --git a/webrtc/modules/bitrate_controller/bitrate_controller_impl.h b/webrtc/modules/bitrate_controller/bitrate_controller_impl.h |
index 26a72dc4191dcc50ad810e00cd1fd11009890858..cb526c157bd9de052bedc0ad596fcea018b3e6c8 100644 |
--- a/webrtc/modules/bitrate_controller/bitrate_controller_impl.h |
+++ b/webrtc/modules/bitrate_controller/bitrate_controller_impl.h |
@@ -66,9 +66,9 @@ class BitrateControllerImpl : public BitrateController { |
bool GetNetworkParameters(uint32_t* bitrate, |
uint8_t* fraction_loss, |
int64_t* rtt); |
- // Updates |send_queue_full_| to |is_full| and returns true if this caused |
- // |send_queue_full_| to be changed. |
- bool UpdateSendQueueStatus(bool is_full); |
+ // Updates |send_queue_ready_| to |is_ready| and returns true if this caused |
+ // |send_queue_ready_| to be changed. |
+ bool UpdateSendQueueStatus(bool is_ready); |
void OnNetworkChanged(uint32_t bitrate, |
uint8_t fraction_loss, // 0 - 255. |
@@ -88,7 +88,7 @@ class BitrateControllerImpl : public BitrateController { |
uint8_t last_fraction_loss_ GUARDED_BY(critsect_); |
int64_t last_rtt_ms_ GUARDED_BY(critsect_); |
uint32_t last_reserved_bitrate_bps_ GUARDED_BY(critsect_); |
- bool send_queue_full_ GUARDED_BY(critsect_); |
+ bool send_queue_ready_ GUARDED_BY(critsect_); |
RTC_DISALLOW_IMPLICIT_CONSTRUCTORS(BitrateControllerImpl); |
}; |